#
# spec file for package bootchart
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define real_version 0.14.8

Name:           bootchart
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  systemd-rpm-macros
Requires:       lsb-release
Requires:       python-cairo
Requires:       python-gtk
Url:            https://github.com/mmeeks/bootchart
Summary:        Boot Process Charting Application
License:        GPL-3.0+
Group:          Development/Tools/Other
Version:        2.%{real_version}
Release:        lp150.1.8
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         https://github.com/xrmx/bootchart/releases/download/%{real_version}/bootchart2-%{real_version}.tar.bz2
Patch:          bootchart-let-RMP-strip-manpages.patch
%{?systemd_requires}

%description
bootchart2 instruments your boot process and provides a tool to render
a graph of what was happening during the boot process later.

%prep
%setup -q -n bootchart2-%{real_version}
%patch -p1

%build
export EARLY_PREFIX=%_prefix
make CFLAGS="%optflags" %{?_smp_mflags}

%install
export PY_LIBDIR=%py_libdir
export PY_SITEDIR=%py_sitedir
export EARLY_PREFIX=%_prefix
export DOCDIR=%_docdir/%name
make install DESTDIR=%{buildroot}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcbootchart2
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcbootchart2-done
%fdupes -s %{buildroot}%{python_sitelib}

%pre
%service_add_pre bootchart2.service bootchart2-done.service bootchart2-done.timer

%post
%service_add_post bootchart2.service bootchart2-done.service bootchart2-done.timer

%preun
%service_del_preun bootchart2.service bootchart2-done.service bootchart2-done.timer

%postun
%service_del_postun bootchart2.service bootchart2-done.service bootchart2-done.timer

%files
%defattr(-,root,root)
%dir %{_libexecdir}/bootchart
%{_docdir}/*
%{_bindir}/pybootchartgui
%{_libexecdir}/bootchart/tmpfs
%{_libexecdir}/bootchart/bootchart-collector
%{_mandir}/man1/bootchart2.1.gz
%{_mandir}/man1/bootchartd.1.gz
%{_mandir}/man1/pybootchartgui.1.gz
%{_mandir}/man1/%{name}*
%{_sbindir}/bootchartd
%{_sbindir}/rcbootchart2
%{_sbindir}/rcbootchart2-done
%{_unitdir}/bootchart2*.service
%{_unitdir}/bootchart2-done.timer
%config(noreplace) /etc/bootchartd.conf
%py_sitedir/pybootchartgui

%changelog
* Thu Jan 12 2017 guillaume@opensuse.org
- Update to version 0.14.8:
  * bootchartd
  - misc collector fixes
  - fix for sparc
  * pybootchartgui
  - Use half the memory when parsing files
- Use full URL as source
* Tue Feb 10 2015 p.drouand@gmail.com
- Update to version 0.14.7
  * bootchartd
  - Use /bin/sh instead of bash
  - Misc coverity fixes
  - Fix systemd regression
  * pybootchartgui
  - Fix merging of logger process #56
- Spec file refactoring
- Remove depreciated mkinitrd-boot.sh and mkinitrd-setup.sh scripts
  files; use provided systemd unit files instead
- Add systemd support; add systemd-rpm-macros build require and
  %%{?systemd_requires}
- Move bootchart stuff to /usr
- Remove obsolete bootchart_init.patch
- Add bootchart-let-RMP-strip-manpages.patch; let RPM gzip itself
  the manpages
- Remove mkinitrd dependency; not needed anymore
- Remove %%system_requires; depreciated
* Fri Oct 19 2012 cfarrell@suse.com
- license update: GPL-3.0+
  See COPYING and e.g. pybootchart -> draw.py
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Nov 15 2010 aj@suse.de
- Fix cmdline parsing for alternative init system (bnc#649513)
* Wed Oct 27 2010 aj@suse.de
- Use RPM_OPT_FLAGS for building.
* Wed Oct 27 2010 aj@suse.de
- Update to bootchart2 0.12.4:
  o various bugfixes
  o display memory usage
  o includes pthread patch.
* Wed Oct 27 2010 aj@suse.de
- Disable initrd support for now as the system will not boot with
  it (bnc#649512).
* Thu Jul 15 2010 michael.meeks@novell.com
- update to bootchart2 0.12.1
  + pybootchartgui
  + pylint cleanup
  + handle empty traces more elegantly
  + add '-t' / '--boot-time' argument (Matthew Bauer)
  + collector
  + now GPLv2
  + add rdinit support for very early initrd tracing
  + cleanup / re-factor code into separate modules
  + re-factor arg parsing, and parse remote process args
  + handle missing bootchartd.conf cleanly
  + move much of bootchartd from shell -> C
  + drop dmesg and uname usage
  + avoid rpm/dpkg with native version reporting
- update to bootchart2 0.12.0
  + collector
  + use netlink PROC_EVENTS to generate parentage data
  + finally kills any need for 'acct' et. al.
  + also removes need to poll /proc => faster
  + cleanup code to K&R, 8 stop tabs.
  + pybootchartgui
  + consume thread parentage data
* Tue Apr 13 2010 michael.meeks@novell.com
- update to bootchart2-0.1.0
  + rendering (Anders Norgaard)
  + fix for unknown exceptions
  + interactive UI (Michael)
  + much faster rendering by manual clipping
  + horizontal scaling
  + remove annoying page-up/down bindings
  + initrd portability & fixes (Federic Crozat)
  + port to Mandriva
  + improved process waiting
  + inittab commenting fix
  + improved initrd detection / jail tagging
  + fix for un-detectable accton behaviour change
  + implement a built-in usleep to help initrd deps (Michael)
- remove 'usleep' dep.
* Mon Mar 15 2010 coolo@novell.com
- make it work on factory's initrd
* Wed Mar 10 2010 coolo@novell.com
- do not require lsb
* Tue Feb  2 2010 michael.meeks@novell.com
- update to bootchart2-0.0.9
  + fixes leaked collector when installed in initrd
- remove README.SUSE - it's obsolete.
* Mon Feb  1 2010 michael.meeks@novell.com
- update to bootchart2-0.0.8
  + fixes some mis-accounting bugs
  + adds the chart filename to the interactive window title
* Thu Jan 21 2010 coolo@novell.com
- call mkinitrd on installing and uninstalling bootchart (bnc#558765)
* Wed Jan 20 2010 michael.meeks@novell.com
- update to bootchart2-0.0.6
  + adds cumulative CPU time graphing
* Wed Jan 20 2010 michael.meeks@novell.com
- remove 'sleep' during transition from initrd, we don't
  need that anymore, and it distorts the profile horribly.
* Tue Jan 19 2010 michael.meeks@novell.com
- update to bootchart2-0.0.5
* Mon Nov 23 2009 michael.meeks@novell.com
- package bootchart2 - a cleaned up, and graunched version
  of the Ubuntu bootchart-collector, and pybootchartgui
  Merge some of Coolo's good work wrt. init scripts etc.
* Sun Aug  9 2009 beineri@opensuse.org
- add postun reminder
* Tue May 19 2009 coolo@suse.de
- don't use java but python (removes noarch)
* Thu Apr 30 2009 coolo@suse.de
- remove mingetty from the list of processes to check for, it's just
  not our target
* Mon Apr  6 2009 coolo@suse.de
- don't kill stapio and blktrace
- redo diff
* Fri Feb  6 2009 coolo@suse.de
- show status of threads too
- only overwrite init if it's default
* Thu Jan 29 2009 coolo@suse.de
- add grep to the list of programs and make it use bash
* Tue Jan 20 2009 coolo@suse.de
- fix initrd profiling and fix autorender support
* Fri Aug  1 2008 coolo@suse.de
- adding a README.SUSE to warn for the situation described in
  bnc#400402
* Thu Jul 24 2008 hare@suse.de
- Install mkinitrd scriptlets correctly.
* Wed Jun 20 2007 coolo@suse.de
- log all initrd scripts
* Tue Jun 19 2007 coolo@suse.de
- make it a bit quicker to change between initrd and
  system
* Tue Jun 19 2007 coolo@suse.de
- first try to bootchart what's in the initrd
* Thu Apr 26 2007 coolo@suse.de
- fix permissions of config files
- make the package noarch
* Mon Sep 25 2006 ro@suse.de
- use source and target 1.4 for java
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 14 2005 coolo@suse.de
- update to 0.9
* Tue Nov  1 2005 coolo@suse.de
- improve support for user land charts
* Tue Oct 11 2005 coolo@suse.de
- update to CVS for one major bug fix
* Tue Aug 23 2005 coolo@suse.de
- don't sleep too long
* Wed Jul 27 2005 coolo@suse.de
- another update from CVS
* Fri Mar 11 2005 coolo@suse.de
- adding fix from CVS
* Thu Mar  3 2005 coolo@suse.de
- update to 0.8 (you have to read INSTALL now)
* Fri Jan 21 2005 coolo@suse.de
- changed the default back to svg for DISPLAY less renderer
* Thu Jan 20 2005 coolo@suse.de
- update to 0.7
* Mon Jan  3 2005 coolo@suse.de
- new version
* Fri Dec 17 2004 coolo@suse.de
- update to the version I use ;)
* Mon Dec  6 2004 coolo@suse.de
- initial version
